@@ -35,13 +35,12 @@
 
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
-//#include <exo/exo.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include "indicator-dialog.h"
 #include "indicator-dialog_ui.h"
 
-#define PLUGIN_WEBSITE  "http://goodies.xfce.org/projects/panel-plugins/xfce4-indicator-plugin"
+#define PLUGIN_WEBSITE  "https://docs.xfce.org/panel-plugins/xfce4-indicator-plugin"
 
 #ifdef LIBXFCE4UI_CHECK_VERSION
 #if LIBXFCE4UI_CHECK_VERSION (4,9,0)
